@@ -18,6 +18,7 @@ __all__ = [
     'tabs',
     'to_html',
     'config2file',
+    'text',
 ]
 
 box = app.box
@@ -30,6 +31,7 @@ markdown = app.markdown
 select = app.select
 cols = app.cols
 tabs = app.tabs
+text = app.text
 plotly = app.plotly
 fns = app.Fns
 
