@@ -10,7 +10,7 @@ from pyvisflow.models.TConfig import TReactData, TConfig
 from pyvisflow.models.TStaticData import TStaticData
 from pyvisflow.models.TWatchInfo import TWatchInfo
 from pyvisflow.models.TComponent import TComponentType
-from pyvisflow.utils.data_gen import get_project_root
+from pyvisflow.utils.data_gen import get_project_root, json_dumps_fn
 from pyvisflow.utils.helper import flatten
 import pandas as pd
 import re
@@ -50,7 +50,7 @@ class App(BoxContainer):
         self._scripts.extend(names)
 
     def pretty_json(self):
-        return json.dumps(self.create_config().dict(), indent=2)
+        return json_dumps_fn(self.create_config().dict(), indent=2)
 
     def config2file(self, file):
         return Path(file).write_text(self.pretty_json(), 'utf8')
