@@ -28,7 +28,7 @@ class Select(_Select):
     @property
     def currentLabels(self):
         p = self.get_prop('currentLabels')
-        return SubscriptableTypePropInfo[str, StrTypePropInfo](p)
+        return SubscriptableTypePropInfo[int, StrTypePropInfo](p)
 
     def _ex_get_react_data(self):
         data = super()._ex_get_react_data()
